yakumo.nova.v2.image.Manager

Package yakumo :: Package nova :: Package v2 :: Module image :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
                  Manager

Manager class for images in Compute API v2

Nested Classes | [hide private]
| resource_class Resource class for images in Compute API v2

Instance Methods | [hide private]
Inherited from `base.Manager`: `__init__`, `create`, `find`, `find_one`, `get`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``compute``'``
| _attr_mapping = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass object `...``
| _hidden_methods = ``[``'``create``'``,` `'``update``'``]``
| _json_resource_key = ``'``image``'``
| _json_resources_key = ``'``images``'``
| _url_resource_path = ``'``/images``'``
| _url_resource_list_path = ``'``/images/detail``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_id_attr`, `_update_method`

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('size', 'O
      S-EXT-IMG-SIZE:size', mapper.Noop), ('min_ram', 'minRam', mapper.Noop)
      , ('min_disk', 'minDisk', mapper.Noop), ('metadata', 'metadata', mappe
      r.Noop), ('status', 'status', mapper.Noop), ('created_at', 'created',
      mapper.Noop), ('updated_at', 'updated', mapper.Noop),]